==> haskell-snap-server-1.1.0.0-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.0.0
id: snap-server-1.1.0.0-lUt7L108Xh8MriT5sCpyy
key: snap-server-1.1.0.0-lUt7L108Xh8MriT5sCpyy
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: bfaf7f837e71845ec2f11b82a5fa2b75
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-server-1.1.0.0
hs-libraries: HSsnap-server-1.1.0.0-lUt7L108Xh8MriT5sCpyy
depends:
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    filepath-1.4.2 io-streams-1.5.0.1-GVnvt4HWgciILzINo2uloz
    io-streams-haproxy-1.0.0.2-Eh74Pn02gnZ504DcfyEpXQ
    lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS mtl-2.2.2
    network-2.7.0.0-AFQUqm7hPUl7GJe3nXsQng
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    snap-core-1.0.3.2-28QKtKnyDW5HIkbjeaeQ4j text-1.2.3.0 time-1.8.0.2
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             io-streams-1.5.0.1-GVnvt4HWgciILzINo2uloz=bd8c76fdd1c3f4137d0e4a1236bde881
             io-streams-haproxy-1.0.0.2-Eh74Pn02gnZ504DcfyEpXQ=f0503b125583fb0a6dcb8aa170877586
             lifted-base-0.2.3.12-EZ86Th71kuIKONQzo515KS=b7feb9ada79ca4aa0bc32a0336d653d1
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.0-AFQUqm7hPUl7GJe3nXsQng=f721cf34b8f5e16aaba2f249d1eefa28
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             snap-core-1.0.3.2-28QKtKnyDW5HIkbjeaeQ4j=19fb02f35b4a40987fa65d7e94786f4f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.0.0-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.0.0
id: snap-server-1.1.0.0-VaXDRYpKMQJGE5L1rVrnM
key: snap-server-1.1.0.0-VaXDRYpKMQJGE5L1rVrnM
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: fbefb5f14db6df9ebb02cd12d1e26650
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-server-1.1.0.0
hs-libraries: HSsnap-server-1.1.0.0-VaXDRYpKMQJGE5L1rVrnM
depends:
    attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    filepath-1.4.2 io-streams-1.5.0.1-3Xk9RbeDrpk1zAdhtInGbG
    io-streams-haproxy-1.0.0.2-Kod3CrLTOb9KeMKnAyOho
    lifted-base-0.2.3.12-FAg1nfG7BqAKj27Z5I0234 mtl-2.2.2
    network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    snap-core-1.0.3.2-GXK3FSbLudj3BPxGFovA1S text-1.2.3.0 time-1.8.0.2
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk=825d47e693044b92530553d85386444f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             io-streams-1.5.0.1-3Xk9RbeDrpk1zAdhtInGbG=5aee8df3f2238416034b8da71969cf64
             io-streams-haproxy-1.0.0.2-Kod3CrLTOb9KeMKnAyOho=d7f809db184485f9cf845b070e9e19ca
             lifted-base-0.2.3.12-FAg1nfG7BqAKj27Z5I0234=7c85494025287996e6fbb8672353d544
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz=593cfbdab1e8a8c0dc553b5ae47d8025
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             snap-core-1.0.3.2-GXK3FSbLudj3BPxGFovA1S=c094668b0983405e174b883f0cc4c224
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=31a73ccc78f384281114d092d52191fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
